Class: Aws::FinSpaceData::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::FinSpaceData::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-finspacedata/client.rb,
sig/client.rbs
Overview
An API client for FinSpaceData. To construct a client, you need to configure a :region and :credentials.
client = Aws::FinSpaceData::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AssociateUserToPermissionGroupResponseSuccess, _CreateChangesetResponseSuccess, _CreateDataViewResponseSuccess, _CreateDatasetResponseSuccess, _CreatePermissionGroupResponseSuccess, _CreateUserResponseSuccess, _DeleteDatasetResponseSuccess, _DeletePermissionGroupResponseSuccess, _DisableUserResponseSuccess, _DisassociateUserFromPermissionGroupResponseSuccess, _EnableUserResponseSuccess, _GetChangesetResponseSuccess, _GetDataViewResponseSuccess, _GetDatasetResponseSuccess, _GetExternalDataViewAccessDetailsResponseSuccess, _GetPermissionGroupResponseSuccess, _GetProgrammaticAccessCredentialsResponseSuccess, _GetUserResponseSuccess, _GetWorkingLocationResponseSuccess, _ListChangesetsResponseSuccess, _ListDataViewsResponseSuccess, _ListDatasetsResponseSuccess, _ListPermissionGroupsByUserResponseSuccess, _ListPermissionGroupsResponseSuccess, _ListUsersByPermissionGroupResponseSuccess, _ListUsersResponseSuccess, _ResetUserPasswordResponseSuccess, _UpdateChangesetResponseSuccess, _UpdateDatasetResponseSuccess, _UpdatePermissionGroupResponseSuccess, _UpdateUserResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_user_to_permission_group(params = {}) ⇒ Types::AssociateUserToPermissionGroupResponse
Adds a user to a permission group to grant permissions for actions a user can perform in FinSpace.
-
#create_changeset(params = {}) ⇒ Types::CreateChangesetResponse
Creates a new Changeset in a FinSpace Dataset.
-
#create_data_view(params = {}) ⇒ Types::CreateDataViewResponse
Creates a Dataview for a Dataset.
-
#create_dataset(params = {}) ⇒ Types::CreateDatasetResponse
Creates a new FinSpace Dataset.
-
#create_permission_group(params = {}) ⇒ Types::CreatePermissionGroupResponse
Creates a group of permissions for various actions that a user can perform in FinSpace.
-
#create_user(params = {}) ⇒ Types::CreateUserResponse
Creates a new user in FinSpace.
-
#delete_dataset(params = {}) ⇒ Types::DeleteDatasetResponse
Deletes a FinSpace Dataset.
-
#delete_permission_group(params = {}) ⇒ Types::DeletePermissionGroupResponse
Deletes a permission group.
-
#disable_user(params = {}) ⇒ Types::DisableUserResponse
Denies access to the FinSpace web application and API for the specified user.
-
#disassociate_user_from_permission_group(params = {}) ⇒ Types::DisassociateUserFromPermissionGroupResponse
Removes a user from a permission group.
-
#enable_user(params = {}) ⇒ Types::EnableUserResponse
Allows the specified user to access the FinSpace web application and API.
-
#get_changeset(params = {}) ⇒ Types::GetChangesetResponse
Get information about a Changeset.
-
#get_data_view(params = {}) ⇒ Types::GetDataViewResponse
Gets information about a Dataview.
-
#get_dataset(params = {}) ⇒ Types::GetDatasetResponse
Returns information about a Dataset.
-
#get_external_data_view_access_details(params = {}) ⇒ Types::GetExternalDataViewAccessDetailsResponse
Returns the credentials to access the external Dataview from an S3 location.
-
#get_permission_group(params = {}) ⇒ Types::GetPermissionGroupResponse
Retrieves the details of a specific permission group.
-
#get_programmatic_access_credentials(params = {}) ⇒ Types::GetProgrammaticAccessCredentialsResponse
Request programmatic credentials to use with FinSpace SDK.
-
#get_user(params = {}) ⇒ Types::GetUserResponse
Retrieves details for a specific user.
-
#get_working_location(params = {}) ⇒ Types::GetWorkingLocationResponse
A temporary Amazon S3 location, where you can copy your files from a source location to stage or use as a scratch space in FinSpace notebook.
-
#list_changesets(params = {}) ⇒ Types::ListChangesetsResponse
Lists the FinSpace Changesets for a Dataset.
-
#list_data_views(params = {}) ⇒ Types::ListDataViewsResponse
Lists all available Dataviews for a Dataset.
-
#list_datasets(params = {}) ⇒ Types::ListDatasetsResponse
Lists all of the active Datasets that a user has access to.
-
#list_permission_groups(params = {}) ⇒ Types::ListPermissionGroupsResponse
Lists all available permission groups in FinSpace.
-
#list_permission_groups_by_user(params = {}) ⇒ Types::ListPermissionGroupsByUserResponse
Lists all the permission groups that are associated with a specific user.
-
#list_users(params = {}) ⇒ Types::ListUsersResponse
Lists all available users in FinSpace.
-
#list_users_by_permission_group(params = {}) ⇒ Types::ListUsersByPermissionGroupResponse
Lists details of all the users in a specific permission group.
-
#reset_user_password(params = {}) ⇒ Types::ResetUserPasswordResponse
Resets the password for a specified user ID and generates a temporary one.
-
#update_changeset(params = {}) ⇒ Types::UpdateChangesetResponse
Updates a FinSpace Changeset.
-
#update_dataset(params = {}) ⇒ Types::UpdateDatasetResponse
Updates a FinSpace Dataset.
-
#update_permission_group(params = {}) ⇒ Types::UpdatePermissionGroupResponse
Modifies the details of a permission group.
-
#update_user(params = {}) ⇒ Types::UpdateUserResponse
Modifies the details of the specified user.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
473 474 475 |
# File 'lib/aws-sdk-finspacedata/client.rb', line 473 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2230 2231 2232 |
# File 'lib/aws-sdk-finspacedata/client.rb', line 2230 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2233 2234 2235 |
# File 'lib/aws-sdk-finspacedata/client.rb', line 2233 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#associate_user_to_permission_group(params = {}) ⇒ Types::AssociateUserToPermissionGroupResponse
Adds a user to a permission group to grant permissions for actions a user can perform in FinSpace.
86 |
# File 'sig/client.rbs', line 86
def associate_user_to_permission_group: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 |
# File 'lib/aws-sdk-finspacedata/client.rb', line 2203 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::FinSpaceData') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-finspacedata' context[:gem_version] = '1.69.0' Seahorse::Client::Request.new(handlers, context) end |
#create_changeset(params = {}) ⇒ Types::CreateChangesetResponse
Creates a new Changeset in a FinSpace Dataset.
99 |
# File 'sig/client.rbs', line 99
def create_changeset: (
|
#create_data_view(params = {}) ⇒ Types::CreateDataViewResponse
Creates a Dataview for a Dataset.
114 |
# File 'sig/client.rbs', line 114
def create_data_view: (
|
#create_dataset(params = {}) ⇒ Types::CreateDatasetResponse
Creates a new FinSpace Dataset.
134 |
# File 'sig/client.rbs', line 134
def create_dataset: (
|
#create_permission_group(params = {}) ⇒ Types::CreatePermissionGroupResponse
Creates a group of permissions for various actions that a user can perform in FinSpace.
162 |
# File 'sig/client.rbs', line 162
def create_permission_group: (
|
#create_user(params = {}) ⇒ Types::CreateUserResponse
Creates a new user in FinSpace.
175 |
# File 'sig/client.rbs', line 175
def create_user: (
|
#delete_dataset(params = {}) ⇒ Types::DeleteDatasetResponse
Deletes a FinSpace Dataset.
191 |
# File 'sig/client.rbs', line 191
def delete_dataset: (
|
#delete_permission_group(params = {}) ⇒ Types::DeletePermissionGroupResponse
Deletes a permission group. This action is irreversible.
202 |
# File 'sig/client.rbs', line 202
def delete_permission_group: (
|
#disable_user(params = {}) ⇒ Types::DisableUserResponse
Denies access to the FinSpace web application and API for the specified user.
213 |
# File 'sig/client.rbs', line 213
def disable_user: (
|
#disassociate_user_from_permission_group(params = {}) ⇒ Types::DisassociateUserFromPermissionGroupResponse
Removes a user from a permission group.
224 |
# File 'sig/client.rbs', line 224
def disassociate_user_from_permission_group: (
|
#enable_user(params = {}) ⇒ Types::EnableUserResponse
Allows the specified user to access the FinSpace web application and API.
236 |
# File 'sig/client.rbs', line 236
def enable_user: (
|
#get_changeset(params = {}) ⇒ Types::GetChangesetResponse
Get information about a Changeset.
259 |
# File 'sig/client.rbs', line 259
def get_changeset: (
|
#get_data_view(params = {}) ⇒ Types::GetDataViewResponse
Gets information about a Dataview.
281 |
# File 'sig/client.rbs', line 281
def get_data_view: (
|
#get_dataset(params = {}) ⇒ Types::GetDatasetResponse
Returns information about a Dataset.
301 |
# File 'sig/client.rbs', line 301
def get_dataset: (
|
#get_external_data_view_access_details(params = {}) ⇒ Types::GetExternalDataViewAccessDetailsResponse
Returns the credentials to access the external Dataview from an S3 location. To call this API:
-
You must retrieve the programmatic credentials.
-
You must be a member of a FinSpace user group, where the dataset that you want to access has
Read Dataset Datapermissions.
312 |
# File 'sig/client.rbs', line 312
def get_external_data_view_access_details: (
|
#get_permission_group(params = {}) ⇒ Types::GetPermissionGroupResponse
Retrieves the details of a specific permission group.
323 |
# File 'sig/client.rbs', line 323
def get_permission_group: (
|
#get_programmatic_access_credentials(params = {}) ⇒ Types::GetProgrammaticAccessCredentialsResponse
Request programmatic credentials to use with FinSpace SDK. For more information, see Step 2. Access credentials programmatically using IAM access key id and secret access key.
334 |
# File 'sig/client.rbs', line 334
def get_programmatic_access_credentials: (
|
#get_user(params = {}) ⇒ Types::GetUserResponse
Retrieves details for a specific user.
357 |
# File 'sig/client.rbs', line 357
def get_user: (
|
#get_working_location(params = {}) ⇒ Types::GetWorkingLocationResponse
A temporary Amazon S3 location, where you can copy your files from a source location to stage or use as a scratch space in FinSpace notebook.
369 |
# File 'sig/client.rbs', line 369
def get_working_location: (
|
#list_changesets(params = {}) ⇒ Types::ListChangesetsResponse
Lists the FinSpace Changesets for a Dataset.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
380 |
# File 'sig/client.rbs', line 380
def list_changesets: (
|
#list_data_views(params = {}) ⇒ Types::ListDataViewsResponse
Lists all available Dataviews for a Dataset.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
393 |
# File 'sig/client.rbs', line 393
def list_data_views: (
|
#list_datasets(params = {}) ⇒ Types::ListDatasetsResponse
Lists all of the active Datasets that a user has access to.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
406 |
# File 'sig/client.rbs', line 406
def list_datasets: (
|
#list_permission_groups(params = {}) ⇒ Types::ListPermissionGroupsResponse
Lists all available permission groups in FinSpace.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
418 |
# File 'sig/client.rbs', line 418
def list_permission_groups: (
|
#list_permission_groups_by_user(params = {}) ⇒ Types::ListPermissionGroupsByUserResponse
Lists all the permission groups that are associated with a specific user.
430 |
# File 'sig/client.rbs', line 430
def list_permission_groups_by_user: (
|
#list_users(params = {}) ⇒ Types::ListUsersResponse
Lists all available users in FinSpace.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
443 |
# File 'sig/client.rbs', line 443
def list_users: (
|
#list_users_by_permission_group(params = {}) ⇒ Types::ListUsersByPermissionGroupResponse
Lists details of all the users in a specific permission group.
455 |
# File 'sig/client.rbs', line 455
def list_users_by_permission_group: (
|
#reset_user_password(params = {}) ⇒ Types::ResetUserPasswordResponse
Resets the password for a specified user ID and generates a temporary one. Only a superuser can reset password for other users. Resetting the password immediately invalidates the previous password associated with the user.
468 |
# File 'sig/client.rbs', line 468
def reset_user_password: (
|
#update_changeset(params = {}) ⇒ Types::UpdateChangesetResponse
Updates a FinSpace Changeset.
480 |
# File 'sig/client.rbs', line 480
def update_changeset: (
|
#update_dataset(params = {}) ⇒ Types::UpdateDatasetResponse
Updates a FinSpace Dataset.
494 |
# File 'sig/client.rbs', line 494
def update_dataset: (
|
#update_permission_group(params = {}) ⇒ Types::UpdatePermissionGroupResponse
Modifies the details of a permission group. You cannot modify a
permissionGroupID.
510 |
# File 'sig/client.rbs', line 510
def update_permission_group: (
|
#update_user(params = {}) ⇒ Types::UpdateUserResponse
Modifies the details of the specified user. You cannot update the
userId for a user.
524 |
# File 'sig/client.rbs', line 524
def update_user: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2223 2224 2225 |
# File 'lib/aws-sdk-finspacedata/client.rb', line 2223 def waiter_names [] end |