Class: Aws::FinSpaceData::Types::DataViewErrorInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::FinSpaceData::Types::DataViewErrorInfo
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-finspacedata/types.rb
Overview
The structure with error messages.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#error_category ⇒ String
The category of the error.
-
#error_message ⇒ String
The text of the error message.
Instance Attribute Details
#error_category ⇒ String
The category of the error.
-
VALIDATION– The inputs to this request are invalid. -
SERVICE_QUOTA_EXCEEDED– Service quotas have been exceeded. Please contact AWS support to increase quotas. -
ACCESS_DENIED– Missing required permission to perform this request. -
RESOURCE_NOT_FOUND– One or more inputs to this request were not found. -
THROTTLING– The system temporarily lacks sufficient resources to process the request. -
INTERNAL_SERVICE_EXCEPTION– An internal service error has occurred. -
CANCELLED– Cancelled. -
USER_RECOVERABLE– A user recoverable error has occurred.
792 793 794 795 796 797 |
# File 'lib/aws-sdk-finspacedata/types.rb', line 792 class DataViewErrorInfo < Struct.new( :error_message, :error_category) SENSITIVE = [] include Aws::Structure end |
#error_message ⇒ String
The text of the error message.
792 793 794 795 796 797 |
# File 'lib/aws-sdk-finspacedata/types.rb', line 792 class DataViewErrorInfo < Struct.new( :error_message, :error_category) SENSITIVE = [] include Aws::Structure end |